==> jc-1.4.0.tar.gz: soot/grimp/GrimpBody__242.h <==
// class soot.grimp.GrimpBody$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1f83438963cdb9a soot_grimp_GrimpBody__242
// @dep_class d048eaf64ce6dc1a soot_jimple_AbstractStmtSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractStmtSwitch

#include "soot/jimple/AbstractStmtSwitch.h"

#ifndef _JC_soot_grimp_GrimpBody__242_H_
#define _JC_soot_grimp_GrimpBody__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_grimp_GrimpBody$object;
struct _jc_soot_jimple_GotoStmt$object;
struct _jc_soot_jimple_IfStmt$object;
struct _jc_soot_jimple_LookupSwitchStmt$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_TableSwitchStmt$object;

// Typedefs
typedef struct _jc_soot_grimp_GrimpBody__242$sub_refs	_jc_soot_grimp_GrimpBody__242$sub_refs;
typedef struct _jc_soot_grimp_GrimpBody__242$sub_nonrefs	_jc_soot_grimp_GrimpBody__242$sub_nonrefs;
typedef struct _jc_soot_grimp_GrimpBody__242$refs	_jc_soot_grimp_GrimpBody__242$refs;
typedef struct _jc_soot_grimp_GrimpBody__242$nonrefs	_jc_soot_grimp_GrimpBody__242$nonrefs;
typedef struct _jc_soot_grimp_GrimpBody__242$object	_jc_soot_grimp_GrimpBody__242$object;

typedef const struct _jc_soot_grimp_GrimpBody__242$vmethods	_jc_soot_grimp_GrimpBody__242$vmethods;
typedef const struct _jc_soot_grimp_GrimpBody__242$vtable	_jc_soot_grimp_GrimpBody__242$vtable;
typedef const struct _jc_soot_grimp_GrimpBody__242$vtype	_jc_soot_grimp_GrimpBody__242$vtype;

// Constructors
extern void _jc_soot_grimp_GrimpBody__242$method$_init$0e284e80fddfaf52(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_soot_grimp_GrimpBody$object *, struct _jc_java_util_HashMap$object *);

// Virtual methods
extern void _jc_soot_grimp_GrimpBody__242$method$caseGotoStmt$9c07a3775a04982e(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *);
extern void _jc_soot_grimp_GrimpBody__242$method$caseIfStmt$7120ce81ab0f0ea8(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *);
extern void _jc_soot_grimp_GrimpBody__242$method$caseLookupSwitchStmt$4d90be6c9b6b8491(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *);
extern void _jc_soot_grimp_GrimpBody__242$method$caseTableSwitchStmt$290b69634db61277(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *);
extern void _jc_soot_grimp_GrimpBody__242$method$defaultCase$1a586a60386d9b21(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_GrimpBody__242$method_info$caseGotoStmt$9c07a3775a04982e;
extern _jc_method _jc_soot_grimp_GrimpBody__242$method_info$caseIfStmt$7120ce81ab0f0ea8;
extern _jc_method _jc_soot_grimp_GrimpBody__242$method_info$caseLookupSwitchStmt$4d90be6c9b6b8491;
extern _jc_method _jc_soot_grimp_GrimpBody__242$method_info$caseTableSwitchStmt$290b69634db61277;
extern _jc_method _jc_soot_grimp_GrimpBody__242$method_info$defaultCase$1a586a60386d9b21;

// Virtual methods structure
struct _jc_soot_grimp_GrimpBody__242$vmethods {
	void	(*caseGotoStmt$9c07a3775a04982e)(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *);
	void	(*caseIfStmt$7120ce81ab0f0ea8)(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *);
	void	(*caseLookupSwitchStmt$4d90be6c9b6b8491)(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *);
	void	(*caseTableSwitchStmt$290b69634db61277)(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *);
	void	(*defaultCase$1a586a60386d9b21)(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_grimp_GrimpBody__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractStmtSwitch$vmethods	soot_jimple_AbstractStmtSwitch;
	_jc_soot_grimp_GrimpBody__242$vmethods	soot_grimp_GrimpBody__242;
};

// Vtype
struct _jc_soot_grimp_GrimpBody__242$vtype {
	_jc_type			type;
	_jc_soot_grimp_GrimpBody__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_GrimpBody__242$sub_refs {
	struct _jc_java_util_HashMap$object	*val__24oldToNew;
	struct _jc_soot_grimp_GrimpBody$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_grimp_GrimpBody__242$refs {
    _jc_soot_grimp_GrimpBody__242$sub_refs	soot_grimp_GrimpBody__242;
    _jc_soot_jimple_AbstractStmtSwitch$sub_refs	soot_jimple_AbstractStmtSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_GrimpBody__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_GrimpBody__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractStmtSwitch$sub_nonrefs	soot_jimple_AbstractStmtSwitch;
    _jc_soot_grimp_GrimpBody__242$sub_nonrefs	soot_grimp_GrimpBody__242;
};

// Object instance structure
struct _jc_soot_grimp_GrimpBody__242$object {
	_jc_soot_grimp_GrimpBody__242$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_GrimpBody__242$vtype	*vtype;
	_jc_soot_grimp_GrimpBody__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_GrimpBody__242$vtype _jc_soot_grimp_GrimpBody__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_GrimpBody__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_GrimpBody__242$class_object;

#endif	/* _JC_soot_grimp_GrimpBody__242_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/GrimpBody__242.h <==
// class soot.grimp.GrimpBody$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1f83438963cdb9a soot_grimp_GrimpBody__242
// @dep_class d048eaf64ce6dc1a soot_jimple_AbstractStmtSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractStmtSwitch

#include "soot/jimple/AbstractStmtSwitch.h"

#ifndef _JC_soot_grimp_GrimpBody__242_H_
#define _JC_soot_grimp_GrimpBody__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_grimp_GrimpBody$object;
struct _jc_soot_jimple_GotoStmt$object;
struct _jc_soot_jimple_IfStmt$object;
struct _jc_soot_jimple_LookupSwitchStmt$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_TableSwitchStmt$object;

// Typedefs
typedef struct _jc_soot_grimp_GrimpBody__242$sub_refs	_jc_soot_grimp_GrimpBody__242$sub_refs;
typedef struct _jc_soot_grimp_GrimpBody__242$sub_nonrefs	_jc_soot_grimp_GrimpBody__242$sub_nonrefs;
typedef struct _jc_soot_grimp_GrimpBody__242$refs	_jc_soot_grimp_GrimpBody__242$refs;
typedef struct _jc_soot_grimp_GrimpBody__242$nonrefs	_jc_soot_grimp_GrimpBody__242$nonrefs;
typedef struct _jc_soot_grimp_GrimpBody__242$object	_jc_soot_grimp_GrimpBody__242$object;

typedef const struct _jc_soot_grimp_GrimpBody__242$vmethods	_jc_soot_grimp_GrimpBody__242$vmethods;
typedef const struct _jc_soot_grimp_GrimpBody__242$vtable	_jc_soot_grimp_GrimpBody__242$vtable;
typedef const struct _jc_soot_grimp_GrimpBody__242$vtype	_jc_soot_grimp_GrimpBody__242$vtype;

// Constructors
extern void _jc_soot_grimp_GrimpBody__242$method$_init$0e284e80fddfaf52(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_soot_grimp_GrimpBody$object *, struct _jc_java_util_HashMap$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_grimp_GrimpBody__242$method$caseGotoStmt$9c07a3775a04982e(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_grimp_GrimpBody__242$method$caseIfStmt$7120ce81ab0f0ea8(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_grimp_GrimpBody__242$method$caseLookupSwitchStmt$4d90be6c9b6b8491(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_grimp_GrimpBody__242$method$caseTableSwitchStmt$290b69634db61277(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_grimp_GrimpBody__242$method$defaultCase$1a586a60386d9b21(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_GrimpBody__242$method_info$caseGotoStmt$9c07a3775a04982e;
extern _jc_method _jc_soot_grimp_GrimpBody__242$method_info$caseIfStmt$7120ce81ab0f0ea8;
extern _jc_method _jc_soot_grimp_GrimpBody__242$method_info$caseLookupSwitchStmt$4d90be6c9b6b8491;
extern _jc_method _jc_soot_grimp_GrimpBody__242$method_info$caseTableSwitchStmt$290b69634db61277;
extern _jc_method _jc_soot_grimp_GrimpBody__242$method_info$defaultCase$1a586a60386d9b21;

// Virtual methods structure
struct _jc_soot_grimp_GrimpBody__242$vmethods {
	void	(*caseGotoStmt$9c07a3775a04982e)(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseIfStmt$7120ce81ab0f0ea8)(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseLookupSwitchStmt$4d90be6c9b6b8491)(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseTableSwitchStmt$290b69634db61277)(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*defaultCase$1a586a60386d9b21)(_jc_env *, struct _jc_soot_grimp_GrimpBody__242$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_GrimpBody__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractStmtSwitch$vmethods	soot_jimple_AbstractStmtSwitch;
	_jc_soot_grimp_GrimpBody__242$vmethods	soot_grimp_GrimpBody__242;
};

// Vtype
struct _jc_soot_grimp_GrimpBody__242$vtype {
	_jc_type			type;
	_jc_soot_grimp_GrimpBody__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_GrimpBody__242$sub_refs {
	struct _jc_java_util_HashMap$object	*val__24oldToNew;
	struct _jc_soot_grimp_GrimpBody$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_grimp_GrimpBody__242$refs {
    _jc_soot_grimp_GrimpBody__242$sub_refs	soot_grimp_GrimpBody__242;
    _jc_soot_jimple_AbstractStmtSwitch$sub_refs	soot_jimple_AbstractStmtSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_GrimpBody__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_GrimpBody__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractStmtSwitch$sub_nonrefs	soot_jimple_AbstractStmtSwitch;
    _jc_soot_grimp_GrimpBody__242$sub_nonrefs	soot_grimp_GrimpBody__242;
};

// Object instance structure
struct _jc_soot_grimp_GrimpBody__242$object {
	_jc_soot_grimp_GrimpBody__242$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_GrimpBody__242$vtype	*vtype;
	_jc_soot_grimp_GrimpBody__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_GrimpBody__242$vtype _jc_soot_grimp_GrimpBody__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_GrimpBody__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_GrimpBody__242$class_object;

#endif	/* _JC_soot_grimp_GrimpBody__242_H_ */
